@@ -398,8 +398,7 @@ def instance_stop(ctx):
 @click.option('-r', '--raw', 'is_raw', is_flag=True, help='Dump raw json response')
 @click.pass_context
 def instance_view(ctx, is_raw):
-    """Quick and dirty instance viewer.
-    """
+    """Quick and dirty instance viewer."""
     session = ctx.obj.session
     job_resource = ctx.obj.job
     instance_resource = get_instance_for_job(session, job_resource)
